@@ -22,10 +22,9 @@
 ;;; Code:
 
 (defun er/add-web-mode-expansions ()
-  (set (make-local-variable er/try-expand-list) 
-        (append
-         er/try-expand-list
-         '(web-mode-mark-and-expand))))
+  (set (make-local-variable 'er/try-expand-list)
+       (append er/try-expand-list
+               '(web-mode-mark-and-expand))))
 
 (add-hook 'web-mode-hook 'er/add-web-mode-expansions)
 
